pub fn assign(func: &Func, order: &Order, live: &Live, env: &Env) -> AssignmentExpand description
Decides where every value in a function lives.
Panics
Panics if a class has no registers to hand out and something in the function is in that class, since that is a target description that does not describe the target the function is for.